@@ -37,7 +37,7 @@ Readonly my $FALSE   => 0;
 Readonly my $EMPTY   => q{};
 Readonly my $NL      => "\n";
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 our %DEFAULT_PROCESSORS = (
   pre       => \&_pre,
@@ -415,6 +415,8 @@ text file. The class exports 1 method (C<process_file>) which invokes
 multiple subroutines that you can override or use in conjunction with
 your custom processors.
 
+I<See L<File::Process::Utils> for additional recipes.>
+
 =head1 EXPORTED METHODS
 
 This module exports 1 method by default (C<process_file>). You can
@@ -711,6 +713,10 @@ processors.  Pass these methods the same list you receive.
 This module is free software. It may be used, redistributed and/or
 modified under the same terms as Perl itself.
 
+=head1 SEE ALSO
+
+L<File::Process:Utils>
+
 =head1 AUTHOR
 
 Rob Lauer - <rlauer6@comcast.net>
